pub struct SetTickDuration(pub Duration);Expand description
Event that can be triggered to update the tick duration.
If the trigger is global, it will update:
Time<Fixed>- the various Timelines
The event can also be triggered for a specific target to update only the components of that target.
Tuple Fields
0: DurationTrait Implementations